import { h } from "@stencil/core";
import classNames from "classnames";
import { getIsExtensionAvailable, getIsMetaMaskAvailable } from "../../visual/unlock-panel/helpers/index";
import { ProviderTypeEnum } from "../../../types/provider.types";
const unlockButtonClasses = {
    statusIcon: 'mvx:fill-teal-400!',
};
export class UnlockButton {
    render() {
        const isExtensionProvider = this.type === ProviderTypeEnum.extension;
        const isMetaMaskProvider = this.type === ProviderTypeEnum.metamask;
        const isDetectableProvider = isExtensionProvider || isMetaMaskProvider;
        const isExtensionInstalled = isExtensionProvider && getIsExtensionAvailable();
        const isMetaMaskInstalled = isMetaMaskProvider && getIsMetaMaskAvailable();
        const shouldShowOpenLabel = isDetectableProvider && (isExtensionInstalled || isMetaMaskInstalled);
        return (h("div", { key: 'fe11c4a869ba98ae6dea52d9696c72b538d77d45', class: { 'unlock-button': true, [this.class]: Boolean(this.class) } }, h("div", { key: '0056662f87e76ac92c2348eb341b20289292c575', class: "unlock-button-label" }, this.label), h("div", { key: 'f5faa75e16ecf2ddf6c11e1c97bbdb2d11eaa5d3', class: {
                'unlock-button-icon': true,
                'clipped': isExtensionProvider,
            } }, this.icon ? this.icon : h("img", { src: this.iconUrl, alt: this.label })), isDetectableProvider && (h("div", { key: '17cda2bce1edc8c7937fbea5f8abb4ccb27faa08', class: "unlock-button-status" }, h("div", { key: '53d837d6375e75d28ba50ca9c7e9ef84cd4f8794', class: "unlock-button-status-text" }, shouldShowOpenLabel ? 'Open' : 'Install'), !shouldShowOpenLabel && (h("mvx-arrow-up-right-icon", { key: '1a4431cc6b5967831fb4d34a7ad0d81ded70ecb1', class: classNames('unlock-button-status-icon', {
                [unlockButtonClasses.statusIcon]: true,
            }) }))))));
    }
    static get is() { return "mvx-unlock-button"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["unlock-button.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["unlock-button.css"]
        };
    }
    static get properties() {
        return {
            "label": {
                "type": "string",
                "attribute": "label",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "iconUrl": {
                "type": "string",
                "attribute": "icon-url",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "icon": {
                "type": "unknown",
                "attribute": "icon",
                "mutable": false,
                "complexType": {
                    "original": "HTMLElement",
                    "resolved": "HTMLElement",
                    "references": {
                        "HTMLElement": {
                            "location": "global",
                            "id": "global::HTMLElement"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            },
            "type": {
                "type": "any",
                "attribute": "type",
                "mutable": false,
                "complexType": {
                    "original": "IProviderBase['type']",
                    "resolved": "string | number | (() => string) | ((pos: number) => string) | ((index: number) => number) | ((...strings: string[]) => string) | ((searchString: string, position?: number) => number) | ((searchString: string, position?: number) => number) | { (that: string): number; (that: string, locales?: string | string[], options?: CollatorOptions): number; (that: string, locales?: LocalesArgument, options?: CollatorOptions): number; } | { (regexp: string | RegExp): RegExpMatchArray; (matcher: { [Symbol.match](string: string): RegExpMatchArray; }): RegExpMatchArray; } | { (searchValue: string | RegExp, replaceValue: string): string; (searchValue: string | RegExp, replacer: (substring: string, ...args: any[]) => string): string; (searchValue: { [Symbol.replace](string: string, replaceValue: string): string; }, replaceValue: string): string; (searchValue: { [Symbol.replace](string: string, replacer: (substring: string, ...args: any[]) => string): string; }, replacer: (substring: string, ...args: any[]) => string): string; } | { (regexp: string | RegExp): number; (searcher: { [Symbol.search](string: string): number; }): number; } | ((start?: number, end?: number) => string) | { (separator: string | RegExp, limit?: number): string[]; (splitter: { [Symbol.split](string: string, limit?: number): string[]; }, limit?: number): string[]; } | ((start: number, end?: number) => string) | (() => string) | { (locales?: string | string[]): string; (locales?: LocalesArgument): string; } | (() => string) | { (locales?: string | string[]): string; (locales?: LocalesArgument): string; } | (() => string) | ((from: number, length?: number) => string) | (() => string) | ((pos: number) => number) | ((searchString: string, position?: number) => boolean) | ((searchString: string, endPosition?: number) => boolean) | { (form: \"NFC\" | \"NFD\" | \"NFKC\" | \"NFKD\"): string; (form?: string): string; } | ((count: number) => string) | ((searchString: string, position?: number) => boolean) | ((name: string) => string) | (() => string) | (() => string) | (() => string) | (() => string) | ((color: string) => string) | { (size: number): string; (size: string): string; } | (() => string) | ((url: string) => string) | (() => string) | (() => string) | (() => string) | (() => string) | ((maxLength: number, fillString?: string) => string) | ((maxLength: number, fillString?: string) => string) | (() => string) | (() => string) | (() => string) | (() => string) | ((regexp: RegExp) => IterableIterator<RegExpExecArray>) | (() => IterableIterator<string>) | ((index: number) => string)",
                    "references": {
                        "IProviderBase": {
                            "location": "import",
                            "path": "types/provider.types",
                            "id": "src/types/provider.types.ts::IProviderBase"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "class": {
                "type": "string",
                "attribute": "class",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
}
//# sourceMappingURL=unlock-button.js.map
