import { h } from "@stencil/core";
import classNames from "classnames";
import { DataTestIdsEnum } from "../../../../constants/dataTestIds.enum";
const TOTAL_ADDRESSES_COUNT = 5000;
export class LedgerAddresses {
    handleAccessWallet(event) {
        event.preventDefault();
        this.accessWallet.emit();
    }
    handleSelectAccount(accountDerivationIndex) {
        return (event) => {
            event.preventDefault();
            this.selectAccount.emit(accountDerivationIndex);
        };
    }
    handlePageChange(event) {
        event.preventDefault();
        event.stopPropagation();
        this.pageChange.emit(event.detail);
    }
    processLedgerAddressIndex(accountDerivation) {
        return Number(accountDerivation.index + 1).toLocaleString();
    }
    render() {
        const isPageChanging = this.accountScreenData.isLoading;
        const isAddressesLoadingInitially = this.accountScreenData.accounts.length === 0;
        const totalPages = Math.ceil(TOTAL_ADDRESSES_COUNT / this.accountScreenData.addressesPerPage);
        const isSelectedWalletOnPage = this.accountScreenData.accounts.some(accountDerivation => accountDerivation.index === this.selectedIndex);
        const isAccessWalletDisabled = !isSelectedWalletOnPage && !isPageChanging;
        const lastIndexOfPage = this.accountScreenData.startIndex + this.accountScreenData.addressesPerPage;
        const isSingleDigitIndex = lastIndexOfPage <= 10;
        const isIndexBelowOneHundred = !isSingleDigitIndex && lastIndexOfPage < 100;
        const isIndexInTheHundreds = !isIndexBelowOneHundred && !isSingleDigitIndex && lastIndexOfPage < 1000;
        const isIndexInTheThousands = lastIndexOfPage >= 1000;
        const ledgerAddressesClasses = {
            buttonTooltip: 'mvx:absolute mvx:top-0 mvx:h-12 mvx:left-0 mvx:right-0',
            preloaderItem: 'mvx:h-16! mvx:border mvx:border-solid mvx:border-transparent mvx:rounded-lg! mvx:flex mvx:items-center mvx:w-full! mvx:p-4',
            preloaderItemCheckbox: 'mvx:h-4! mvx:mr-2 mvx:min-w-4! mvx:w-4! mvx:rounded-full! mvx:bg-neutral-700!',
            preloaderItemAddress: 'mvx:w-40! mvx:h-4! mvx:bg-neutral-700! mvx:rounded-lg! mvx:mr-auto',
            preloaderItemBalance: 'mvx:w-24! mvx:h-4! mvx:bg-neutral-700! mvx:rounded-lg! mvx:ml-2',
            preloaderItemIndex: classNames('mvx:mr-2 mvx:h-4! mvx:bg-neutral-700! mvx:rounded-lg!', {
                'mvx:w-9!': isSingleDigitIndex,
                'mvx:w-10!': isIndexBelowOneHundred,
                'mvx:w-13!': isIndexInTheHundreds,
                'mvx:w-17!': isIndexInTheThousands,
            }),
        };
        if (isAddressesLoadingInitially) {
            return h("mvx-ledger-intro", { isAwaiting: true });
        }
        return (h("div", { class: "ledger-addresses" }, h("div", { class: "ledger-addresses-label" }, "Choose the wallet you want to access"), h("div", { class: "ledger-addresses-wrapper" }, h("div", { class: { 'ledger-addresses-preloader': true, 'visible': isPageChanging } }, Array.from({ length: this.accountScreenData.addressesPerPage }, () => (h("mvx-preloader", { class: classNames('ledger-addresses-preloader-item', ledgerAddressesClasses.preloaderItem) }, h("mvx-preloader", { class: classNames('ledger-addresses-preloader-item-checkbox', ledgerAddressesClasses.preloaderItemCheckbox) }), h("mvx-preloader", { class: classNames('ledger-addresses-preloader-item-index', ledgerAddressesClasses.preloaderItemIndex) }), h("mvx-preloader", { class: classNames('ledger-addresses-preloader-item-address', ledgerAddressesClasses.preloaderItemAddress) }), h("mvx-preloader", { class: classNames('ledger-addresses-preloader-item-balance', ledgerAddressesClasses.preloaderItemBalance) }))))), h("div", { class: { 'ledger-addresses-list': true, 'visible': !isPageChanging } }, this.accountScreenData.accounts.map(accountDerivation => (h("div", { class: { 'ledger-addresses-list-item': true, 'checked': accountDerivation.index === this.selectedIndex }, onClick: this.handleSelectAccount(accountDerivation.index) }, h("div", { class: { 'ledger-addresses-list-item-checkbox': true, 'checked': accountDerivation.index === this.selectedIndex } }), h("div", { class: {
                'ledger-addresses-list-item-index': true,
                'checked': accountDerivation.index === this.selectedIndex,
                'narrow': isSingleDigitIndex,
                'middle': isIndexBelowOneHundred,
                'larger': isIndexInTheHundreds,
                'largest': isIndexInTheThousands,
            } }, "#", this.processLedgerAddressIndex(accountDerivation)), h("mvx-trim-text", { text: accountDerivation.address, class: "ledger-addresses-list-item-address" }), h("div", { class: "ledger-addresses-list-item-balance" }, accountDerivation.usdValue)))))), h("mvx-pagination", { totalPages: totalPages, isDisabled: isPageChanging, onPageChange: (event) => this.handlePageChange(event), currentPage: this.accountScreenData.startIndex / this.accountScreenData.addressesPerPage + 1 }), h("div", { class: "ledger-addresses-button-wrapper" }, isAccessWalletDisabled && (h("div", { class: "ledger-addresses-button-tooltip-wrapper" }, h("mvx-tooltip", { trigger: h("div", { class: { 'ledger-addresses-button-tooltip': true, [ledgerAddressesClasses.buttonTooltip]: true } }) }, "You have to select a wallet from the list that you want to access."))), h("button", { "data-testid": DataTestIdsEnum.confirmBtn, onClick: this.handleAccessWallet.bind(this), class: { 'ledger-addresses-button': true, 'loading': isPageChanging, 'disabled': isAccessWalletDisabled } }, h("span", { class: "ledger-addresses-button-label" }, isPageChanging ? 'Loading Wallets...' : 'Access Wallet'), isPageChanging && h("mvx-spinner-icon", null)))));
    }
    static get is() { return "mvx-ledger-addresses"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["ledger-addresses.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["ledger-addresses.css"]
        };
    }
    static get properties() {
        return {
            "accountScreenData": {
                "type": "unknown",
                "attribute": "account-screen-data",
                "mutable": false,
                "complexType": {
                    "original": "IAccountScreenData",
                    "resolved": "IAccountScreenData",
                    "references": {
                        "IAccountScreenData": {
                            "location": "import",
                            "path": "../ledger.types",
                            "id": "src/components/functional/ledger/ledger.types.ts::IAccountScreenData"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            },
            "selectedIndex": {
                "type": "number",
                "attribute": "selected-index",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
    static get events() {
        return [{
                "method": "accessWallet",
                "name": "accessWallet",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }, {
                "method": "selectAccount",
                "name": "selectAccount",
                "bubbles": false,
                "cancelable": true,
                "composed": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }, {
                "method": "pageChange",
                "name": "pageChange",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                }
            }];
    }
}
//# sourceMappingURL=ledger-addresses.js.map
