import { faInfoCircle } from "@fortawesome/free-solid-svg-icons";
import { h } from "@stencil/core";
import { EventBus } from "../../../utils/EventBus";
import { NotificationsFeedEventsEnum } from "./notifications-feed.types";
export class NotificationsFeed {
    constructor() {
        this.isOpen = false;
        this.pendingTransactions = [];
        this.transactionsHistory = [];
        this.eventBus = new EventBus();
        this.closeEventTimeout = null;
        this.handleClose = () => {
            this.isOpen = false;
            this.eventBus.publish(NotificationsFeedEventsEnum.CLOSE_NOTIFICATIONS_FEED);
        };
        this.handleClear = () => {
            this.eventBus.publish(NotificationsFeedEventsEnum.CLEAR_NOTIFICATIONS_FEED_HISTORY);
        };
        this.handleViewAll = () => {
            this.isOpen = true;
        };
    }
    clearTimeouts() {
        if (this.closeEventTimeout) {
            clearTimeout(this.closeEventTimeout);
            this.closeEventTimeout = null;
        }
    }
    disconnectedCallback() {
        this.clearTimeouts();
        this.eventBus.unsubscribe(NotificationsFeedEventsEnum.PENDING_TRANSACTIONS_UPDATE, this.pendingTransactionsUpdate.bind(this));
        this.eventBus.unsubscribe(NotificationsFeedEventsEnum.TRANSACTIONS_HISTORY_UPDATE, this.transactionsHistoryUpdate.bind(this));
        this.eventBus.unsubscribe(NotificationsFeedEventsEnum.OPEN_NOTIFICATIONS_FEED, this.handleViewAll.bind(this));
    }
    async getEventBus() {
        return this.eventBus;
    }
    render() {
        var _a, _b, _c;
        const hasActivity = ((_a = this.transactionsHistory) === null || _a === void 0 ? void 0 : _a.length) > 0;
        const hasPending = ((_b = this.pendingTransactions) === null || _b === void 0 ? void 0 : _b.length) > 0;
        return (h("mvx-side-panel", { key: 'c36ea4c77fb44ae82c73163577710368f5037c62', isOpen: this.isOpen, panelTitle: "Notifications Feed", onClose: this.handleClose }, h("div", { key: '997dcfce30f7f5ec7444a761f4cf4b67ca36ed71', class: "feed-content" }, h("div", { key: '9bd69fe7605e5093214c8519b24abbc8a2b0917c', class: "notifications-info" }, h("mvx-fa-icon", { key: 'b42ade0a811c4cae08d732b91811bba616ad1835', class: "info-icon", icon: faInfoCircle }), "This feed is stored in your browser and will be reset when a new session is started.", h("fa-icon", { key: 'bc77f7fa0f1c440106290bdb4666e1fd48f098ec', class: "info-icon", icon: faInfoCircle })), hasPending && (h("div", { key: 'cbe14fc61e63d7e64d15599308d9a25bfa645b5d', class: "notifications-container" }, h("div", { key: '11266006fea54637c659ae982080f67d857f76a1', class: "processing-status" }, "Processing..."), (_c = this.pendingTransactions) === null || _c === void 0 ? void 0 :
            _c.map(toast => h("mvx-transaction-toast", Object.assign({ fullWidth: true }, toast))))), h("div", { key: 'f1b6244520366dfedb4f3b632e98bda6b1f560f3', class: "activity-section" }, h("div", { key: '1dc00bda801dbd1c8422480217d2c9f633ae1bd8', class: "activity-header" }, h("h3", { key: '74264b12f642ad2815d3debd3a14771f8e27974c', class: "activity-title" }, "Activity"), hasActivity && (h("button", { key: 'dd00129c76d46de98e1b9d45e1eb4bf92e3030b7', class: "clear-button", onClick: this.handleClear }, "Clear"))), h("div", { key: '890cc1c8d238a03531a3567d4652017f2456a2c5', class: "activity-list" }, hasActivity ? (this.transactionsHistory.map(transaction => h("mvx-transaction-list-item", { transaction: transaction }))) : (h("div", { class: "no-activity" }, "No activity to show")))))));
    }
    pendingTransactionsUpdate(payload) {
        this.pendingTransactions = [...payload];
    }
    transactionsHistoryUpdate(payload) {
        this.transactionsHistory = [...payload];
    }
    componentDidLoad() {
        this.eventBus.subscribe(NotificationsFeedEventsEnum.PENDING_TRANSACTIONS_UPDATE, this.pendingTransactionsUpdate.bind(this));
        this.eventBus.subscribe(NotificationsFeedEventsEnum.TRANSACTIONS_HISTORY_UPDATE, this.transactionsHistoryUpdate.bind(this));
        this.eventBus.subscribe(NotificationsFeedEventsEnum.OPEN_NOTIFICATIONS_FEED, this.handleViewAll.bind(this));
    }
    static get is() { return "mvx-notifications-feed"; }
    static get originalStyleUrls() {
        return {
            "$": ["notifications-feed.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["notifications-feed.css"]
        };
    }
    static get states() {
        return {
            "isOpen": {},
            "pendingTransactions": {},
            "transactionsHistory": {}
        };
    }
    static get methods() {
        return {
            "getEventBus": {
                "complexType": {
                    "signature": "() => Promise<IEventBus>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "IEventBus": {
                            "location": "import",
                            "path": "utils/EventBus",
                            "id": "src/utils/EventBus.ts::IEventBus"
                        }
                    },
                    "return": "Promise<IEventBus>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
}
//# sourceMappingURL=notifications-feed.js.map
