import { forceUpdate, h } from "@stencil/core";
import { DataTestIdsEnum } from "../../../constants/dataTestIds.enum";
import { EventBus } from "../../../utils/EventBus";
import { PendingTransactionsEventsEnum } from "./pending-transactions-panel.types";
export class PendingTransactionstPanel {
    constructor() {
        this.eventBus = new EventBus();
        this.isOpen = false;
        this.data = {
            isPending: false,
            title: '',
            subtitle: '',
        };
    }
    componentDidLoad() {
        this.eventBus.subscribe(PendingTransactionsEventsEnum.DATA_UPDATE, this.dataUpdate.bind(this));
        this.eventBus.subscribe(PendingTransactionsEventsEnum.OPEN_PENDING_TRANSACTIONS_PANEL, this.handleOpen.bind(this));
        this.eventBus.subscribe(PendingTransactionsEventsEnum.CLOSE_PENDING_TRANSACTIONS, this.onClose.bind(this, { isUserClick: false }));
    }
    disconnectedCallback() {
        this.eventBus.unsubscribe(PendingTransactionsEventsEnum.DATA_UPDATE, this.dataUpdate.bind(this));
        this.eventBus.unsubscribe(PendingTransactionsEventsEnum.OPEN_PENDING_TRANSACTIONS_PANEL, this.handleOpen.bind(this));
        this.eventBus.unsubscribe(PendingTransactionsEventsEnum.CLOSE_PENDING_TRANSACTIONS, this.onClose.bind(this, { isUserClick: false }));
    }
    handleOpen() {
        this.isOpen = true;
    }
    handleClose() {
        this.isOpen = false;
        this.onClose({ isUserClick: true });
    }
    onClose(props = { isUserClick: true }) {
        this.isOpen = false;
        if (props.isUserClick) {
            this.eventBus.publish(PendingTransactionsEventsEnum.CLOSE_PENDING_TRANSACTIONS);
        }
    }
    dataUpdate(payload) {
        if (payload.shouldClose) {
            return this.onClose({ isUserClick: false });
        }
        this.isOpen = true;
        this.data = Object.assign({}, payload);
        forceUpdate(this);
    }
    async getEventBus() {
        return this.eventBus;
    }
    render() {
        return (h("mvx-side-panel", { key: '6ee617fdf370521acd2720a5f02cde04a7c2728f', isOpen: this.isOpen, panelClassName: "pending-transactions-panel", onClose: this.handleClose.bind(this) }, h("div", { key: '5c7ad49f8dc242c8e1b4d362a7b17273e93e71dc', class: "pending-transactions-content" }, h("div", { key: 'cb9b820c550399bebd9eee5abb712c5296450906', class: "pending-transactions-header" }, h("h2", { key: 'c1fb6808982c1035ca969cce3c774db3581c4600', "data-testid": DataTestIdsEnum.pendingTransactionsTitle }, this.data.title), h("h4", { key: '40ef5e95ce6c4c28d8aa6dc955d8a1246217f32c', "data-testid": DataTestIdsEnum.pendingTransactionsSubtitle }, this.data.subtitle)), h("div", { key: '8e146d24890012d68e989e16da6617af0e6441b4', class: "pending-transactions-body" }, h("button", { key: 'fd9231b35ca190b26e2aaa09ac2fcaf4bdcccf84', class: "close-button", onClick: this.handleClose.bind(this) }, "Close")))));
    }
    static get is() { return "mvx-pending-transactions-panel"; }
    static get originalStyleUrls() {
        return {
            "$": ["pending-transactions-panel.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["pending-transactions-panel.css"]
        };
    }
    static get properties() {
        return {
            "data": {
                "type": "unknown",
                "attribute": "data",
                "mutable": false,
                "complexType": {
                    "original": "IPendingTransactionsPanelData",
                    "resolved": "IPendingTransactionsPanelData",
                    "references": {
                        "IPendingTransactionsPanelData": {
                            "location": "import",
                            "path": "./pending-transactions-panel.types",
                            "id": "src/components/functional/pending-transactions-panel/pending-transactions-panel.types.ts::IPendingTransactionsPanelData"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "defaultValue": "{\n    isPending: false,\n    title: '',\n    subtitle: '',\n  }"
            }
        };
    }
    static get states() {
        return {
            "isOpen": {}
        };
    }
    static get methods() {
        return {
            "getEventBus": {
                "complexType": {
                    "signature": "() => Promise<IEventBus>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "IEventBus": {
                            "location": "import",
                            "path": "utils/EventBus",
                            "id": "src/utils/EventBus.ts::IEventBus"
                        }
                    },
                    "return": "Promise<IEventBus>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
}
//# sourceMappingURL=pending-transactions-panel.js.map
