var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s)
        if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
            t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { h } from "@stencil/core";
import { DataTestIdsEnum } from "../../../../../constants/dataTestIds.enum";
import { formatAddress } from "../../../../../utils/formatAddress";
import state from "../../signTransactionsPanelStore";
export class SignTransaction {
    constructor() {
        this.isConfirming = false;
        this.previousIndex = -1;
    }
    componentWillRender() {
        const { currentIndex } = state.commonData;
        if (this.previousIndex !== -1 && currentIndex !== this.previousIndex) {
            this.isConfirming = false;
        }
        this.previousIndex = currentIndex;
    }
    onConfirm() {
        this.isConfirming = true;
        state.onConfirm();
    }
    getSignButtonProps() {
        const { needsSigning, providerName } = state.commonData;
        const confirmText = providerName ? `Confirm on ${providerName}` : 'Confirm';
        if (needsSigning) {
            return {
                'signText': this.isConfirming ? confirmText : 'Sign',
                'disabled': state.isWaitingForSignature || this.isConfirming,
                'data-testid': DataTestIdsEnum.signTransactionBtn,
                'onClick': this.onConfirm.bind(this),
            };
        }
        return {
            'signText': 'Next',
            'disabled': false,
            'data-testid': DataTestIdsEnum.signNextTransactionBtn,
            'onClick': this.onConfirm.bind(this),
        };
    }
    getBackButtonProps() {
        const { transactionsCount, currentIndex } = state.commonData;
        const isMultipleTransactions = transactionsCount > 1;
        if (!isMultipleTransactions) {
            return {};
        }
        if (currentIndex === 0) {
            return {
                'data-testid': DataTestIdsEnum.signCancelBtn,
                'backButtonText': 'Cancel',
                'onClick': state.onCancel,
            };
        }
        return {
            'data-testid': DataTestIdsEnum.signBackBtn,
            'backButtonText': 'Back',
            'onClick': state.onBack,
            'disabled': state.isWaitingForSignature || this.isConfirming,
        };
    }
    getHighlightedData() {
        const { data, highlight } = state.commonData;
        if (!highlight || !data) {
            return data;
        }
        const parts = data.split(highlight);
        return (h("span", null, parts.map((part, index) => (h("span", null, h("span", { class: "data-content" }, part), index < parts.length - 1 && h("span", { class: "highlight" }, highlight))))));
    }
    render() {
        const { receiver, scCall } = state.commonData;
        const _a = this.getSignButtonProps(), { signText } = _a, signButtonProps = __rest(_a, ["signText"]);
        const _b = this.getBackButtonProps(), { backButtonText } = _b, backButtonProps = __rest(_b, ["backButtonText"]);
        const highlightedData = this.getHighlightedData();
        return (h("div", { key: 'b295899c9841959af470860f282e0c9d8b940a83', class: "transaction-container" }, this.header, h("div", { key: '17d8c2a8b77333e8828f8adf80bfa3a8cf0469aa', class: "receiver-container" }, h("p", { key: '56f152aaa23ab0cad8146dd106703d11ccdbf4cb' }, "To"), h("p", { key: 'a769273f04813a456b9b73fe5dc9013a886525ff' }, formatAddress(receiver, 40))), h("mvx-transaction-fee-component", { key: '87bdfb523441a0f33168c05fc0e72397a384343a' }), scCall && (h("div", { key: '346a10a0ae8ebe3f0059f67985d05b28b0b3de89', class: "data-container" }, h("p", { key: '3a45869e8f0fb91dad1c766cb22d89324c36c75a' }, "Smart Contract Call"), h("div", { key: '2931dab9e7f30c372b23f16ab957cdbbd47af620', class: "data-content-container" }, scCall))), h("div", { key: 'a786a7184ddc0bfd23253c2812355f9d2e9447df', class: "data-container" }, h("p", { key: '691807712e168ef5e5732d532f7855a8d5d12f86' }, "Data"), h("div", { key: '52d9b2c488c5bbeaaa42cf5b99a27d79db012e87', class: "data-content-container" }, highlightedData)), h("div", { key: 'b773d89e5b4ffcabc6325b6f51f8769cb8b21eef', class: "sign-button-container" }, h("button", Object.assign({ key: '7a9e3477a52451da568b196908f17eff31f0b9ed', class: "sign-button" }, signButtonProps), signText), backButtonText && (h("button", Object.assign({ key: '39a05d31bdbc209e0f7aa78bf173225bf2722c11', class: "sign-back-button" }, backButtonProps), backButtonText)))));
    }
    static get is() { return "mvx-sign-transaction-component"; }
    static get originalStyleUrls() {
        return {
            "$": ["sign-transaction-component.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["sign-transaction-component.css"]
        };
    }
    static get properties() {
        return {
            "header": {
                "type": "unknown",
                "attribute": "header",
                "mutable": false,
                "complexType": {
                    "original": "VNode",
                    "resolved": "VNode",
                    "references": {
                        "VNode": {
                            "location": "import",
                            "path": "@stencil/core",
                            "id": "node_modules::VNode"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            }
        };
    }
    static get states() {
        return {
            "isConfirming": {}
        };
    }
}
//# sourceMappingURL=sign-transaction-component.js.map
