import { Fragment, h } from "@stencil/core";
import classNames from "classnames";
const DEFAULT_INFINITE_ANIMATION_DURATION = 30;
export class ToastProgress {
    constructor() {
        this.currentTimestamp = Date.now() / 1000;
        this.hasTimeElapsed = false;
        this.expectedTransactionDuration = 0;
        this.secondsPassedSinceStart = 0;
        this.shouldShowProgressBar = false;
        this.percentagePassedSinceStart = 0;
        this.shouldQuickFill = false;
        this.infiniteProgressDelay = 0;
        this.infinitePercentagePassedSinceStart = 0;
        this.infinitePercentageAnimationDuration = DEFAULT_INFINITE_ANIMATION_DURATION + (this.endTime - this.startTime) * 2;
    }
    componentWillLoad() {
        this.updateProgress();
    }
    handleTimeChange() {
        this.updateProgress();
    }
    updateProgress() {
        this.shouldShowProgressBar = Boolean(this.endTime) && Boolean(this.startTime);
        if (!this.shouldShowProgressBar) {
            this.shouldQuickFill = true;
            this.timeElapsedTimeoutReference = setTimeout(() => (this.hasTimeElapsed = true), 500);
            return;
        }
        this.currentTimestamp = Date.now() / 1000;
        this.expectedTransactionDuration = this.endTime - this.startTime;
        this.secondsPassedSinceStart = this.currentTimestamp - this.startTime;
        this.percentagePassedSinceStart = this.expectedTransactionDuration > 0 ? (this.secondsPassedSinceStart / this.expectedTransactionDuration) * 100 : 0;
        this.infiniteProgressDelay = Math.max(0, this.expectedTransactionDuration - this.secondsPassedSinceStart);
        this.infinitePercentagePassedSinceStart = (this.secondsPassedSinceStart / (this.expectedTransactionDuration + this.infinitePercentageAnimationDuration)) * 100;
    }
    disconnectedCallback() {
        if (this.timeElapsedTimeoutReference) {
            clearTimeout(this.timeElapsedTimeoutReference);
        }
    }
    render() {
        return (h(Fragment, { key: 'b504cfe9c797b4a2fd2d882edb0b2aee147f4477' }, h("div", { key: '55e308458b388c9015b04050cc54a6300e600ee9', class: "transaction-toast-bar-wrapper", style: { opacity: this.hasTimeElapsed ? '0' : '1' } }, h("div", { key: 'ff52548fb5839cfe5a901950f350373ec5c3d70f', class: "transaction-toast-bar-fixed", style: {
                '--animation-duration': `${this.expectedTransactionDuration}s`,
                '--start-width': `${this.percentagePassedSinceStart}%`,
            } }), h("div", { key: 'f2bfb8cc93ca5f85add4fb7fa295a7bbbf469df7', class: "transaction-toast-bar infinite" }, h("div", { key: 'edab2589b071aa8c6be02bd7e77bb397876c9b75', class: "transaction-toast-bar-line", style: {
                '--start-width': `${this.infinitePercentagePassedSinceStart}%`,
                '--animation-duration': `${this.infinitePercentageAnimationDuration}s`,
                '--animation-delay': `${this.infiniteProgressDelay}s`,
            } })), h("div", { key: '2501e89ffa9f0767cc649a065e876980bc80708f', class: classNames('transaction-toast-bar fill', {
                animate: this.shouldQuickFill,
            }) })), h("div", { key: '3f7ff6ed3e9188d7f412845860fa01024af7d389', class: "transaction-toast-bar-content" }, h("slot", { key: '4e9b7df2a4ba7cf16f5e77710f1648be01e3bd4a' }))));
    }
    static get is() { return "mvx-transaction-toast-progress"; }
    static get originalStyleUrls() {
        return {
            "$": ["transaction-toast-progress.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["transaction-toast-progress.css"]
        };
    }
    static get properties() {
        return {
            "startTime": {
                "type": "number",
                "attribute": "start-time",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "endTime": {
                "type": "number",
                "attribute": "end-time",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "currentTimestamp": {},
            "hasTimeElapsed": {},
            "expectedTransactionDuration": {},
            "secondsPassedSinceStart": {},
            "shouldShowProgressBar": {},
            "percentagePassedSinceStart": {},
            "shouldQuickFill": {},
            "infiniteProgressDelay": {},
            "infinitePercentagePassedSinceStart": {},
            "infinitePercentageAnimationDuration": {}
        };
    }
    static get watchers() {
        return [{
                "propName": "startTime",
                "methodName": "handleTimeChange"
            }, {
                "propName": "endTime",
                "methodName": "handleTimeChange"
            }];
    }
}
//# sourceMappingURL=transaction-toast-progress.js.map
