import { h } from "@stencil/core";
import classNames from "classnames";
const paginationEllipsisFormClasses = {
    buttonIcon: 'mvx:p-[10px] mvx:hover:!fill-teal-400',
};
export class PaginationEllipsisForm {
    constructor() {
        this.pageValue = '';
        this.isVisible = false;
        this.handleInput = this.handleInput.bind(this);
        this.handleSubmit = this.handleSubmit.bind(this);
        this.handleKeyDown = this.handleKeyDown.bind(this);
        this.handleInputReference = this.handleInputReference.bind(this);
    }
    handleInputReference(inputElement) {
        this.inputElement = inputElement;
    }
    handleKeyDown(event) {
        if (event.code === 'Enter') {
            event.preventDefault();
            this.handleSubmit(event);
        }
        if (['Equal', 'Minus', 'Period', 'KeyE', 'Comma'].includes(event.code)) {
            event.preventDefault();
            return;
        }
    }
    handleInput(event) {
        const input = event.target;
        const isBelowMax = parseFloat(input.value) <= this.maxPageToSearchFor;
        if (isBelowMax) {
            this.pageValue = input.value;
        }
        else {
            input.value = this.pageValue;
        }
    }
    handleSubmit(event) {
        if (!this.pageValue) {
            return;
        }
        event.preventDefault();
        this.search.emit(parseInt(this.pageValue === '0' ? '1' : this.pageValue));
    }
    handleVisibilityChange(newValue) {
        if (newValue && this.inputElement) {
            this.inputElement.focus();
        }
    }
    render() {
        return (h("div", { key: '97f6eea417db7bf3dea2812b9352eefbc492b66d', class: "pagination-ellipsis-form", onClick: (event) => event.stopPropagation() }, h("label", { key: '573c95696820c31ca3d16a8a82e0bcdf290d7bc0', htmlFor: "paginationSearch", class: "pagination-ellipsis-form-field-label" }, "Page"), h("div", { key: '208973ff240fabc0e792b509e00d7daf2e2ecb35', class: "pagination-ellipsis-form-field" }, h("input", { key: '0c619f2d388214cfff93f59012951a94c4f71072', type: "number", autoFocus: true, autoComplete: "off", id: "paginationSearch", value: this.pageValue, name: "paginationSearch", onInput: this.handleInput, max: this.maxPageToSearchFor, onKeyDown: this.handleKeyDown, ref: this.handleInputReference, class: "pagination-ellipsis-form-field-input" }), h("div", { key: '1617dba47ceaefb4200d11326569f5ee0d03cac5', class: "pagination-ellipsis-form-button", onClick: this.handleSubmit }, h("mvx-magnifying-glass-icon", { key: '5bb55a943fc6502a3edb108666a7bade814b4cdc', class: classNames('pagination-ellipsis-form-button-icon', paginationEllipsisFormClasses.buttonIcon) })))));
    }
    static get is() { return "mvx-pagination-ellipsis-form"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["pagination-ellipsis-form.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["pagination-ellipsis-form.css"]
        };
    }
    static get properties() {
        return {
            "maxPageToSearchFor": {
                "type": "number",
                "attribute": "max-page-to-search-for",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "isVisible": {
                "type": "boolean",
                "attribute": "is-visible",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            }
        };
    }
    static get states() {
        return {
            "pageValue": {}
        };
    }
    static get events() {
        return [{
                "method": "search",
                "name": "search",
                "bubbles": false,
                "cancelable": true,
                "composed": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                }
            }];
    }
    static get watchers() {
        return [{
                "propName": "isVisible",
                "methodName": "handleVisibilityChange"
            }];
    }
}
//# sourceMappingURL=pagination-ellipsis-form.js.map
