import { h } from "@stencil/core";
import { getPagination } from "./helpers";
export class Pagination {
    constructor() {
        this.currentPage = 1;
        this.isDisabled = false;
        this.activeTooltipIndex = null;
        this.isTooltipOpen = false;
    }
    watchCurrentPage(newValue) {
        if (newValue !== this.currentPageIndex) {
            this.currentPageIndex = newValue;
        }
    }
    handleTooltipStatus(isOpen) {
        this.isTooltipOpen = isOpen;
    }
    handlePageClick(newPageIndex) {
        if (newPageIndex === this.currentPageIndex) {
            return;
        }
        this.currentPageIndex = newPageIndex;
        this.pageChange.emit(newPageIndex);
    }
    handleEdgePageClick(pageToNavigateTo) {
        return (event) => {
            event.preventDefault();
            this.handlePageClick(pageToNavigateTo);
        };
    }
    isCurrentPageActive(paginationItem) {
        return parseFloat(paginationItem) === this.currentPageIndex;
    }
    isInTheHundreds(paginationItem) {
        return parseFloat(paginationItem) && parseFloat(paginationItem) >= 100;
    }
    componentWillLoad() {
        this.currentPageIndex = this.currentPage;
    }
    render() {
        const isLeftToggleDisabled = this.currentPageIndex === 1;
        const isRightToggleDisabled = this.currentPageIndex === this.totalPages;
        const paginationItems = getPagination({ currentPage: this.currentPageIndex, totalPages: this.totalPages });
        return (h("div", { key: '3a948da78f6105452b99423fc72216cb8dd18cb2', class: { pagination: true, [this.class]: Boolean(this.class) } }, h("span", { key: '904db17732d29b60054fb2cf6ceceb5f0169914d', onClick: this.handleEdgePageClick(1), class: { 'pagination-angle': true, 'disabled': this.isDisabled, 'inactive': isLeftToggleDisabled } }, h("mvx-angles-left-icon", { key: '843269c50397329212c4195ae007ac31365c46f5', class: "pagination-angle-icon" })), h("div", { key: 'ba81445bca6fc88e5d59e7f542380f2fd70ba7bb', onClick: this.handleEdgePageClick(this.currentPageIndex - 1), class: { 'pagination-edge-button': true, 'disabled': this.isDisabled, 'inactive': isLeftToggleDisabled } }, h("mvx-angle-left-icon", { key: '82c4740228a54ac9a10b814f956944edc9b5e079', class: "pagination-edge-button-icon" })), h("div", { key: '0ae837b34dab986402ac4aef8f030df361a623eb', class: "pagination-items" }, paginationItems.map((paginationItem, paginationItemIndex) => (h("div", { class: { 'pagination-item-wrapper': true, 'disabled': this.isDisabled } }, parseFloat(paginationItem) ? (h("div", { onClick: () => this.handlePageClick(Number(paginationItem)), class: {
                'pagination-item': true,
                'active': this.isCurrentPageActive(paginationItem),
                'hundreds': this.isInTheHundreds(paginationItem),
            } }, h("span", { class: "pagination-item-text" }, paginationItem))) : (h("mvx-tooltip", { triggerOnClick: true, trigger: h("mvx-pagination-ellipsis", { isActive: this.isTooltipOpen && this.activeTooltipIndex === paginationItemIndex }), onTriggerRender: (event) => {
                this.activeTooltipIndex = paginationItemIndex;
                this.handleTooltipStatus(event.detail);
            } }, !this.isDisabled && (h("mvx-pagination-ellipsis-form", { isVisible: this.isTooltipOpen, maxPageToSearchFor: this.totalPages, onSearch: (event) => this.handlePageClick(event.detail) })))))))), h("div", { key: 'b7fa193ea446cf194585c192295a136ad0053749', onClick: this.handleEdgePageClick(this.currentPageIndex + 1), class: { 'pagination-edge-button': true, 'disabled': this.isDisabled, 'inactive': isRightToggleDisabled } }, h("mvx-angle-right-icon", { key: 'a73ad7434061c2127ad97244bb3e042e1872110d', class: "pagination-edge-button-icon" })), h("span", { key: '774f5c5c3ee18a1bce5f290849544a4de0b977ad', onClick: this.handleEdgePageClick(this.totalPages), class: { 'pagination-angle': true, 'disabled': this.isDisabled, 'inactive': isRightToggleDisabled } }, h("mvx-angles-right-icon", { key: 'a144167a0ea4c10cf6ed0cdebc573965e8263f38', class: "pagination-angle-icon" }))));
    }
    static get is() { return "mvx-pagination"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["pagination.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["pagination.css"]
        };
    }
    static get properties() {
        return {
            "currentPage": {
                "type": "number",
                "attribute": "current-page",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "1"
            },
            "totalPages": {
                "type": "number",
                "attribute": "total-pages",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "isDisabled": {
                "type": "boolean",
                "attribute": "is-disabled",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "class": {
                "type": "string",
                "attribute": "class",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "activeTooltipIndex": {},
            "isTooltipOpen": {},
            "currentPageIndex": {}
        };
    }
    static get events() {
        return [{
                "method": "pageChange",
                "name": "pageChange",
                "bubbles": false,
                "cancelable": true,
                "composed": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                }
            }];
    }
    static get watchers() {
        return [{
                "propName": "currentPage",
                "methodName": "watchCurrentPage"
            }];
    }
}
//# sourceMappingURL=pagination.js.map
