import { h } from "@stencil/core";
export class Tooltip {
    constructor() {
        this.isTooltipVisible = false;
        this.position = 'top';
        this.triggerOnClick = false;
        this.handleEllipsisClick = this.handleEllipsisClick.bind(this);
        this.handleFocusOut = this.handleFocusOut.bind(this);
    }
    setTooltipVisible(isTooltipVisible) {
        this.isTooltipVisible = isTooltipVisible;
        this.triggerRender.emit(this.isTooltipVisible);
    }
    handleEllipsisClick(event) {
        if (!this.triggerOnClick) {
            return;
        }
        event.preventDefault();
        this.setTooltipVisible(!this.isTooltipVisible);
    }
    handleFocusOut(event) {
        const relatedTarget = event.relatedTarget;
        const currentTarget = event.currentTarget;
        if (!currentTarget.contains(relatedTarget)) {
            this.setTooltipVisible(false);
        }
    }
    handleMouseEvent(isTooltipVisible) {
        if (this.triggerOnClick) {
            return;
        }
        return (event) => {
            event.preventDefault();
            this.setTooltipVisible(isTooltipVisible);
        };
    }
    render() {
        return (h("div", { key: '462aa8de8d88f13eddbf9111a85c67a35c3b7318', onClick: this.handleEllipsisClick, onMouseEnter: this.handleMouseEvent(true), onMouseLeave: this.handleMouseEvent(false), class: { tooltip: true, [this.class]: Boolean(this.class) } }, this.isTooltipVisible && (h("div", { key: 'e19e1ba584f47e153a8de3cde6a87c8f9f98438f', class: { 'tooltip-content-wrapper': true, [this.position]: true } }, h("div", { key: 'fc55e7ac97c120a84413b3a4c7c9fdd9aa69b367', class: { 'tooltip-content': true, [this.position]: true }, tabIndex: -1, onFocusout: this.handleFocusOut, onClick: (event) => event.stopPropagation() }, h("slot", { key: '3bbce44a13ab4ed94c14570054b9c144567a2aee' })))), h("span", { key: '04235441d37b67204f1448f14f90c851c82da0ba', class: "tooltip-trigger" }, this.trigger)));
    }
    static get is() { return "mvx-tooltip"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["tooltip.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["tooltip.css"]
        };
    }
    static get properties() {
        return {
            "position": {
                "type": "string",
                "attribute": "position",
                "mutable": false,
                "complexType": {
                    "original": "'top' | 'bottom'",
                    "resolved": "\"bottom\" | \"top\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'top'"
            },
            "triggerOnClick": {
                "type": "boolean",
                "attribute": "trigger-on-click",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "trigger": {
                "type": "unknown",
                "attribute": "trigger",
                "mutable": false,
                "complexType": {
                    "original": "HTMLElement",
                    "resolved": "HTMLElement",
                    "references": {
                        "HTMLElement": {
                            "location": "global",
                            "id": "global::HTMLElement"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            },
            "class": {
                "type": "string",
                "attribute": "class",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "isTooltipVisible": {}
        };
    }
    static get events() {
        return [{
                "method": "triggerRender",
                "name": "triggerRender",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                }
            }];
    }
}
//# sourceMappingURL=tooltip.js.map
