import { h } from "@stencil/core";
import { ProviderTypeEnum } from "../../../../../types/provider.types";
import { getProviderButtonIcon } from "../../helpers";
const getProviderIntroText = (providerType) => {
    switch (providerType) {
        case ProviderTypeEnum.extension:
            return 'Open the MultiversX Browser Extension to connect to your wallet.';
        case ProviderTypeEnum.metamask:
            return 'Open the MetaMask Browser Extension to connect to your wallet.';
        case ProviderTypeEnum.passkey:
            return 'Use your predefined passkey to connect to your wallet.';
        case ProviderTypeEnum.crossWindow:
            return 'Follow the steps on MultiversX Web Wallet to connect to your wallet.';
    }
};
export class UnlockProviderIntro {
    constructor() {
        this.provider = null;
    }
    render() {
        const providerType = this.provider ? this.provider.type : null;
        const isExtensionProvider = providerType === ProviderTypeEnum.extension;
        const extensionProviderIconBaseSize = 150;
        const extensionProviderIconWidth = extensionProviderIconBaseSize + (15 / 100) * extensionProviderIconBaseSize;
        const extensionProviderIconHeight = extensionProviderIconBaseSize + (10 / 100) * extensionProviderIconBaseSize;
        const providerIntroIcon = getProviderButtonIcon(providerType);
        const providerIntroText = getProviderIntroText(providerType);
        if (!this.provider) {
            return null;
        }
        if (this.provider.type === ProviderTypeEnum.ledger) {
            return h("mvx-ledger-intro", { onConnect: this.access.emit });
        }
        return (h("div", { class: "unlock-provider-intro" }, isExtensionProvider ? (h("div", { class: "unlock-provider-intro-icon" }, h("mvx-extension-provider-icon", { width: extensionProviderIconWidth, height: extensionProviderIconHeight }))) : (h("div", { class: "unlock-provider-intro-icon" }, providerIntroIcon)), h("div", { class: "unlock-provider-intro-title" }, "Requesting Connection"), providerIntroText && h("div", { class: "unlock-provider-intro-text" }, providerIntroText)));
    }
    static get is() { return "mvx-unlock-provider-intro"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["unlock-provider-intro.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["unlock-provider-intro.css"]
        };
    }
    static get properties() {
        return {
            "provider": {
                "type": "unknown",
                "attribute": "provider",
                "mutable": false,
                "complexType": {
                    "original": "IProviderBase | null",
                    "resolved": "IProviderBase<ProviderTypeEnum>",
                    "references": {
                        "IProviderBase": {
                            "location": "import",
                            "path": "types/provider.types",
                            "id": "src/types/provider.types.ts::IProviderBase"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "defaultValue": "null"
            }
        };
    }
    static get events() {
        return [{
                "method": "access",
                "name": "access",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }];
    }
}
//# sourceMappingURL=unlock-provider-intro.js.map
